.. prompttrail documentation master file, created by
   sphinx-quickstart on Wed Aug 30 18:30:56 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PromptTrail!
=======================

PromptTrail is a lightweight library to help you build something with LLM.

PromptTrail aims to provide:

- **Unified LLM Interface**: a unified interface to access various LLM models
- **Agent as Code**: simple and intuitive DSL to build agent (conversation flow) with code
- **Developer Tools for LLM**: various tools enable mocking, logging, debugging


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   quickstart
   prompttrail
